/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef COMMON_H
#define COMMON_H

#include <QString>
#include <QStringList>

/**
* \brief Static class providing convenience functions for the application
*/
class Common {
public:
	/**
	* \brief Initialize variables that the Common class needs to work
	*
	* Call this function at the beginning of the application.
	*/
	static void init();

	/**
	* \brief Retrieve a string of all the video filters
	* \return a QString of all the video filters
	*
	* You can use this as part of the filter string for QFileDialog::open().
	*/
	static QString videoFilterString();

	/**
	* \brief Retrieve a list of strings of all the video filters
	* \return a list of QStrings of all the video filters
	*
	* One use case is for auto-completion using QCompleter.
	*/
	static QStringList videoFilterList();

	/**
	* \brief Retrieve a string of all the audio filters
	* \return a QString of all the audio filters
	*
	* You can use this as part of the filter string for QFileDialog::open().
	*/
	static QString audioFilterString();

	/**
	* \brief Retrieve a list of strings of all the audio filters
	* \return a list of QStrings of all the audio filters
	*
	* One use case is for auto-completion using QCompleter.
	*/
	static QStringList audioFilterList();

	/**
	* \brief Retrieve a string of all the subtitle filters
	* \return a QString of all the subtitle filters
	*
	* You can use this as part of the filter string for QFileDialog::open().
	*/
	static QString subFilterString();

	/**
	* \brief Retrieve a list of strings of all the subtitle filters
	* \return a list of QStrings of all the subtitle filters
	*
	* One use case is for auto-completion using QCompleter.
	*/
	static QStringList subFilterList();

	/**
	* \brief Formatted error message
	* \param message error message
	* \return formatted error message
	*
	* Formats an error message and returns the formatted error message as a QString.
	*/
	static QString error(QString message);

	/**
	* \brief Generate readable position from a given number of seconds
	* \param sec Number of seconds
	* \return readable position in HH:mm:ss
	*/
	static QString readablePosition(int sec);

private:
	static QStringList videoFilters;
	static QStringList audioFilters;
	static QStringList subFilters;
};

#endif
