/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "core.h"
#include "mplayerprocess.h"
#include <QObject>
#include <QTime>

#include <QDebug>

Core::Core(QObject *parent) : QObject(parent) {
	_proc = 0;
}

Core::~Core() {
	// Let's stop the running process peacefully before exiting the core first
	deleteProcess();
}

void Core::deleteProcess() {
	if (_proc) {
		if (_proc->state() != QProcess::NotRunning) {
			_proc->write("quit\n");
			if (!_proc->waitForFinished(5000)) _proc->kill();
		}
		disconnect(_proc);
		delete _proc;
		_proc = 0;
	}
}

void Core::createAnalysisProcess(QString fileName) {
	deleteProcess();
	_proc = new MPlayerProcess(MPlayerProcess::Analysis, this);
	_proc->setProcRunCommand("mplayer -frames 0 -identify -vo null -ao null \"" + fileName + "\"");
}

void Core::createPreviewProcess(QString fileName, int wid) {
	deleteProcess();
	_proc = new MPlayerProcess(MPlayerProcess::Preview, this);
	QString strWid("");
	if (wid) strWid = " -wid " + QString::number(wid);
	// -input conf=/usr/share/smplayer/input.conf
	_proc->setProcRunCommand("mplayer -identify -zoom -slave" + strWid + " \"" + fileName + "\"");
}

void Core::seekMediaAbs(int pos) {
	QString seek("seek " + QString::number(pos) + " 2\n");
	_proc->write(seek.toLocal8Bit());
}

void Core::seekMediaRel(int pos) {
	QString seek("seek " + QString::number(pos) + " 0\n");
	_proc->write(seek.toLocal8Bit());
}
