/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef CORE_H
#define CORE_H

#include <QObject>
#include <QString>

class MPlayerProcess;
class QWidget;

/**
* \brief The Core class is where all the action happens.
*
* The purpose of the Core class is to do behind-the-scenes calculations.
* This way, a user interface can be put on top of the Core class,
* and this will translate itself in multiple possible user interfaces,
* for example one graphical user interface and one command line interface.
*/
class Core : public QObject {
	Q_OBJECT
public:
	/**
	* \brief Constructor
	* \param parent Optional parent widget
	*/
	Core(QObject *parent = 0);

	/// Destructor
	~Core();

	/**
	* \brief Access the process that's running in the Core class.
	* \return pointer to the running process
	*
	* Interface with the external running process by calling functions of Core::proc()
	*/
	MPlayerProcess *proc() {return _proc;};

public slots:
	/**
	* \brief Create new external process for video analysis
	* \param fileName filename of the video to analyze
	*
	* The new process will use mplayer for the video analysis.
	*/
	void createAnalysisProcess(QString fileName);

	/**
	* \brief Create new external process for video preview
	* \param fileName filename of the video to preview
	* \param wid optional window ID if the preview has to be rendered on a widget
	*
	* The new process will use mplayer for the video preview.
	*/
	void createPreviewProcess(QString fileName, int wid = 0);

	/**
	* \brief Seek in the current media file, absolute mode
	* \param pos Absolute position in seconds
	*/
	void seekMediaAbs(int pos);

	/**
	* \brief Seek in the current media file, relative mode
	* \param pos Relative position in seconds
	*/
	void seekMediaRel(int pos);

private:
	void deleteProcess();
	MPlayerProcess *_proc;
};

#endif
