/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "ui_main.h"
#include "audiotracks.h"

class Core;

/**
* \brief Main window of the graphical user interface
*/
class MainWindow : public QMainWindow {
	Q_OBJECT
public:
	/**
	* \brief Constructor
	* \param parent Optional parent widget
	*/
	MainWindow(QWidget *parent = 0);

	/// Destructor
	~MainWindow();

private slots:
	void analyseMedia();
	void stopMedia();
	void showAbout();

	// Input connections
	void enableSubs(bool enable);
	void enableAudio(bool enable);
	void setAudioExt(bool external);
	void browseVideo();
	void browseSub();
	void browseAudio();
	void newVideo(const QString &fileName);

	// Preview connections
	void enablePreview(bool enable);
	void setPaused(bool pause);
	void playPreview();
	void setPosition(int sec);
	void setLength(int sec);
	void seekMedia1mL();
	void seekMedia1mR();
	void seekMedia10sL();
	void seekMedia10sR();

	// Encoding connections
	void calcBitrate();

private:
	Core *core;
	Ui::MainWindow ui;
	QString prevDirectory;
};

#endif
