/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef MEDIA_H
#define MEDIA_H

#include "audiotracks.h"
class AudioTrackList;

/**
* \brief A media file
*/
class Media {
public:
	/**
	* \brief State of the loaded media file
	*/
	enum MediaState {
		Stopped, /**< The media is stopped or not loaded */
		Playing, /**< The media is playing */
		Paused /**< The media is paused */
	};

	/**
	* \brief Reset the media file (discard all media information)
	*/
	static void reset();

	/**
	* \brief Retrieve media activity
	* \return \li \c true if the media is active
	*         \li \c false if the media is not active
	*/
	static bool active() {return _active;};

	/**
	* \brief Set media activity
	* \param active Active or not
	*/
	static void setActive(bool active) {_active = active;};

	/**
	* \brief Retrieve media validity
	* \return \li \c true if the media is a valid media file
	*         \li \c false if the media is not a valid media file
	*/
	static bool ok() {return _ok;};

	/**
	* \brief Set media validity
	* \param ok Valid or not
	*/
	static void setOk(bool ok) {_ok = ok;};

	/**
	* \brief Retrieve the current media state
	* \return State of the media file
	*/
	static MediaState state() {return _state;};

	/**
	* \brief Set the media state
	* \param state New media state
	*/
	static void setState(MediaState state) {_state = state;};

	/**
	* \brief Full audio track list for this media file
	*/
	static AudioTrackList audioList;
private:
	static bool _active;
	static bool _ok;
	static MediaState _state;
};

#endif
