/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef MPLAYERPROCESS_H
#define MPLAYERPROCESS_H

#include <QProcess>

/**
* \brief An mplayer process
*/
class MPlayerProcess : public QProcess {
	Q_OBJECT
public:
	/**
	* \brief Type of the process
	*/
	enum ProcType {
		Analysis, /**< This process is used for media analysis */
		Preview /**< This process is used for media preview */
	};

	/// Constructor
	MPlayerProcess(ProcType type, QObject *parent = 0);

	/// Destructor
	~MPlayerProcess();

	/**
	* \brief Retrieve process type
	* \return type of the process
	*/
	ProcType type() {return _type;};

	/**
	* \brief Set the full run command for the process
	* \param procRunCommand The full run command (example: "/path/filename -parameter")
	*
	* This sets the run command that the process will use when it starts.
	*/
	void setProcRunCommand(QString procRunCommand) {_procRunCommand = procRunCommand;};

	/**
	* \brief Run the actual process
	*/
	void runProcess();

signals:
	/**
	* \brief The process has detected that media playback has started playing
	*/
	void playbackStarted();

	/**
	* \brief The process has detected that media playback has paused
	* \param paused True if playback is paused; False if playback is resumed
	*/
	void playbackPaused(bool paused);

	/**
	* \brief The process has detected the video resolution of the media file
	* \param w Width in pixels
	* \param h Height in pixels
	*/
	void gotResolution(int w, int h);

	/**
	* \brief The position of the playing media has changed
	* \param sec New position in seconds
	*/
	void updatePosition(int sec);

	/**
	* \brief Length in seconds of this media file
	* \param sec Length in secondss
	*/
	void gotLength(int sec);

private slots:
	void processBytes();
	void end();

private:
	void processLine(QString line);
	void processAudioLine(int id, QString desc = "", QString type = "");
	ProcType _type;
	QString _procRunCommand;
	int prevPosition;
};

#endif
