/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "mplayerwidget.h"
#include "media.h"
#include <QPaintEvent>
#include <QPainter>

//#include <QDebug>

//// Screen ////

MPlayerScreen::MPlayerScreen(QWidget *parent) : QWidget(parent) {
	setAttribute(Qt::WA_NoSystemBackground);
	setAttribute(Qt::WA_StaticContents);
	setAttribute(Qt::WA_PaintOnScreen);
	setAttribute(Qt::WA_PaintUnclipped);
}

MPlayerScreen::~MPlayerScreen() {
}

void MPlayerScreen::paintEvent(QPaintEvent *e) {
	QPainter p(this);
	p.eraseRect(e->rect());
}

//// Widget ////

MPlayerWidget::MPlayerWidget(QWidget *parent) : MPlayerScreen(parent) {
}

MPlayerWidget::~MPlayerWidget() {
}

void MPlayerWidget::applyResolution(int w, int h) {
	double ratio;
	if (w > h) {
		ratio = (double)w/320.0;
		w = 320;
		h = int((double)h/ratio);
		move(0, int((240-h)/2.0));
	} else { // TODO: test this else
		ratio = (double)h/240.0;
		h = 240;
		w = int((double)w/ratio);
		move(int((320-w)/2.0), 0);
	}
	resize(w, h);
}

void MPlayerWidget::paintEvent(QPaintEvent *e) {
	if (!Media::active()) {
		MPlayerScreen::paintEvent(e);
		QPainter p(this);
		QPen pen(QBrush(Qt::white), 2);
		QFont font;
		font.setBold(true);
		font.setPixelSize(30);
		p.setPen(pen);
		p.setFont(font);
		p.setRenderHint(QPainter::TextAntialiasing);
		p.drawText(QRectF(0, 0, 320, 240), Qt::AlignCenter, "PREVIEW");
	}
}

//// Container ////

MPlayerContainer::MPlayerContainer(QWidget *parent) : MPlayerScreen(parent) {
	mplayerWidget = new MPlayerWidget(this);
	unloadMedia();
}

MPlayerContainer::~MPlayerContainer() {
}

void MPlayerContainer::unloadMedia() {
	mplayerWidget->move(0, 0);
	mplayerWidget->resize(320, 240);
	mplayerWidget->update();
}
