/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef MPLAYERWIDGET_H
#define MPLAYERWIDGET_H

#include <QWidget>

//// Screen ////

/**
* \brief Generic screen class
*/
class MPlayerScreen : public QWidget {
	Q_OBJECT
public:
	/**
	* \brief Constructor
	* \param parent Optional parent widget
	*/
	MPlayerScreen(QWidget *parent = 0);

	/// Destructor
	~MPlayerScreen();

protected:
	virtual void paintEvent(QPaintEvent *e);
};

//// Widget ////

/**
* \brief Actual widget where mplayer can paint on
*/
class MPlayerWidget : public MPlayerScreen {
	Q_OBJECT
public:
	/**
	* \brief Constructor
	* \param parent Optional parent widget
	*/
	MPlayerWidget(QWidget *parent = 0);

	/// Destructor
	~MPlayerWidget();

public slots:
	/**
	* \brief Resize and move the widget to fit and center itself in the container
	* \param w Width of the media file
	* \param h Height of the media file
	*/
	void applyResolution(int w, int h);

protected:
	virtual void paintEvent(QPaintEvent *e);
};

//// Container ////

/**
* \brief Widget container that holds the widget where mplayer will paint on
*/
class MPlayerContainer : public MPlayerScreen {
	Q_OBJECT
public:
	/**
	* \brief Constructor
	* \param parent Optional parent widget
	*/
	MPlayerContainer(QWidget *parent = 0);

	/// Destructor
	~MPlayerContainer();

	/**
	* \brief Pointer to widget for mplayer
	* \return Pointer to the widget where mplayer will paint on
	*/
	MPlayerWidget *widget() {return mplayerWidget;};

public slots:
	/**
	* \brief Unload the media from the preview screen
	*/
	void unloadMedia();

private:
	MPlayerWidget *mplayerWidget;
};

#endif
