/*  D2vid - video conversion software for Cowon D2 portable media player
    Copyright (C) 2008 Wesley Stessens <wesley@ubuntu.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "previewslider.h"

#include <QDebug>

PreviewSlider::PreviewSlider(QWidget *parent) : QSlider(parent) {
	userUpdate = Normal;
	setSingleStep(10);
	setPageStep(60);
	connect(this, SIGNAL(sliderPressed()), this, SLOT(setUserUpdate()));
	connect(this, SIGNAL(sliderReleased()), this, SLOT(unsetUserUpdate()));
	connect(this, SIGNAL(valueChanged(int)), this, SLOT(valueChangedRewrite(int)));
}

PreviewSlider::~PreviewSlider() {
}

void PreviewSlider::setUserUpdate() {
	userUpdate = UserGrabbed;
}

void PreviewSlider::unsetUserUpdate() {
	userUpdate = UserReleased;
}

void PreviewSlider::setSliderValue(int val) {
	// We set this to a negative value so we can easily check whether this is a value that is
	// coming from the core by using this function, or whether the user changed the value manually.
	// In valueChangedRewrite() we'll reverse this value so it becomes positive again.
	if (userUpdate == Normal && val < 0) valueChangedRewrite(-val);
}

void PreviewSlider::valueChangedRewrite(int val) {
	if (val < 0) {
		// Change received from core
		setValue(-val);
	} else {
		// User change
		emit sliderValueChanged(val);
	}
}
